@@ -54,7 +54,7 @@ class HardwareType(str, Enum):
     EXYNOS_2200 = "Exynos 2200"
 
     @property
-    def is_future(self):
+    def is_future(self) -> bool:
         return self in [
             HardwareType.HAILO8,
             HardwareType.AMBARELLA,
@@ -73,7 +73,7 @@ class HardwareType(str, Enum):
         ]
 
     @property
-    def is_deprecated(self):
+    def is_deprecated(self) -> bool:
         return self in [
             HardwareType.K80,
             HardwareType.CPU,
@@ -339,7 +339,7 @@ class MapHardwareTypeToEnvironment(str, Enum):
     NUC_TIGER_LAKE = HardwareEnvironment.PREMISE.value
 
 
-class MapHardwareTypeToDefaultBatchSizeList(list, Enum):
+class MapHardwareTypeToDefaultBatchSizeList(list, Enum):  # type: ignore[type-arg]
     V100 = get_enum_values(BatchSize)
     K80 = get_enum_values(BatchSize)
     T4 = get_enum_values(BatchSize)
@@ -386,7 +386,7 @@ class HardwareImageDistribution(str, Enum):
     J502 = "j502"
 
     @property
-    def python_version(self):
+    def python_version(self) -> str:
         dist_to_version = {
             HardwareImageDistribution.J46: "3.6",
             HardwareImageDistribution.J50: "3.8",
@@ -397,9 +397,9 @@ class HardwareImageDistribution(str, Enum):
 
 class MapHardwareTypeToImageDistribution(str, Enum):
     NANO = HardwareImageDistribution.J46.value
-    XAVIER = HardwareImageDistribution.J502.value
+    XAVIER = HardwareImageDistribution.J46.value
     XAVIER_AGX = HardwareImageDistribution.J46.value
-    ORIN = HardwareImageDistribution.J502.value
+    ORIN = HardwareImageDistribution.J50.value
     ORIN_NX = HardwareImageDistribution.J502.value
     ORIN_NANO = HardwareImageDistribution.J502.value
 
